xadrpy
======

`xadrpy` it's easy django toolkit

I M P O R T A N T
-----------------
*This is a development version of `xadrpy`. It may contains bugs. This is not a product ready solution.*

Setup
-----

Install the package with [pip](http://pip.openplans.org/) or [git](http://git-scm.com/):

    pip install xadrpy
    
    # or ...
    
    pip install -e git://github.com/pacsee/xadrpy.git#egg=xadrpy

Detailed documentation
----------------------
The documentation language is hungarian (at the moment).

See: docs/ folder

Teaser
------
* router - append urls from database
* api - json api interface (i will implement oauth2)
* worker - daemonized background processes
* access - full access control
* i18n - tools for database translating
* social - easy social connect, social plugins
* models - extra fields - extends django (DictField, JSONField, Crypted field, ...)
* contrib.backoffice - extjs interface with django backend
* contrib.emails - Email handling (with templates, attachements, translation...)
* contrib.themes - Theme (layout, skin) handling
* contrib.pages - easy cms engine
* contrib.blogs - easy blog engine (extends pages)
* contrib.shop - easy shop and catalogue engine (extends pages)

...

But i'm working on it...